import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Creates a new OAuth app for a Wix Headless client.
 *
 * Use this API to enable headless functionality for a Wix site. An OAuth app allows external sites or apps to securely access your site's data and services using Wix APIs.
 */
export declare function createOAuthApp(payload: object): RequestOptionsFactory<any>;
/** Retrieves an OAuth app by ID. */
export declare function getOAuthApp(payload: object): RequestOptionsFactory<any>;
/**
 * Updates an OAuth app.
 *
 *
 * Only fields provided in `mask.paths` are updated.
 *
 * You can update the following fields:
 * + `name`
 * + `description`
 * + `allowedDomain`
 * + `loginUrl`
 * + `logoutUrl`
 * + `technology`
 */
export declare function updateOAuthApp(payload: object): RequestOptionsFactory<any>;
/**
 * Deletes an OAuth app by ID.
 *
 *
 * > **Note:** After you delete an OAuth app, an external client can no longer make API calls by authenticating with its client ID.
 */
export declare function deleteOAuthApp(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a list of OAuth apps, given the provided paging, filtering, and sorting.
 *
 *
 * Query OAuth Apps runs with these defaults, which you can override:
 * + Results are sorted by `id` in descending order.
 * + `paging.offset` is `0`.
 */
export declare function queryOAuthApps(payload: object): RequestOptionsFactory<any>;
/**
 * Generates a secret for an existing OAuth app.
 *
 *
 * > **Note:** You can only generate a secret once for each OAuth app, and the secret can't be retrieved later. Store the secret securely.
 */
export declare function generateOAuthAppSecret(payload: object): RequestOptionsFactory<any>;
