"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateOAuthAppSecret = exports.queryOAuthApps = exports.deleteOAuthApp = exports.updateOAuthApp = exports.getOAuthApp = exports.createOAuthApp = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const timestamp_2 = require("@wix/sdk-runtime/transformations/timestamp");
const field_mask_1 = require("@wix/sdk-runtime/transformations/field-mask");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveWixHeadlessV1OAuthAppServiceUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/oauth-app-service',
                destPath: '',
            },
            {
                srcPath: '/oauth-app',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/oauth-app',
                destPath: '',
            },
        ],
        'api._api_base_domain_': [
            {
                srcPath: '/oauth-app-service',
                destPath: '',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_auth-management_o-auth-apps';
/**
 * Creates a new OAuth app for a Wix Headless client.
 *
 * Use this API to enable headless functionality for a Wix site. An OAuth app allows external sites or apps to securely access your site's data and services using Wix APIs.
 */
function createOAuthApp(payload) {
    function __createOAuthApp({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'oAuthApp.createdDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'POST',
            methodFqn: 'wix.headless.v1.OAuthAppService.CreateOAuthApp',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'oAuthApp.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __createOAuthApp;
}
exports.createOAuthApp = createOAuthApp;
/** Retrieves an OAuth app by ID. */
function getOAuthApp(payload) {
    function __getOAuthApp({ host }) {
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'GET',
            methodFqn: 'wix.headless.v1.OAuthAppService.GetOAuthApp',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps/{oAuthAppId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'oAuthApp.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __getOAuthApp;
}
exports.getOAuthApp = getOAuthApp;
/**
 * Updates an OAuth app.
 *
 *
 * Only fields provided in `mask.paths` are updated.
 *
 * You can update the following fields:
 * + `name`
 * + `description`
 * + `allowedDomain`
 * + `loginUrl`
 * + `logoutUrl`
 * + `technology`
 */
function updateOAuthApp(payload) {
    function __updateOAuthApp({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: field_mask_1.transformSDKFieldMaskToRESTFieldMask,
                paths: [{ path: 'mask' }],
            },
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'oAuthApp.createdDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'PATCH',
            methodFqn: 'wix.headless.v1.OAuthAppService.UpdateOAuthApp',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps/{oAuthApp.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'oAuthApp.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __updateOAuthApp;
}
exports.updateOAuthApp = updateOAuthApp;
/**
 * Deletes an OAuth app by ID.
 *
 *
 * > **Note:** After you delete an OAuth app, an external client can no longer make API calls by authenticating with its client ID.
 */
function deleteOAuthApp(payload) {
    function __deleteOAuthApp({ host }) {
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'DELETE',
            methodFqn: 'wix.headless.v1.OAuthAppService.DeleteOAuthApp',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps/{oAuthAppId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __deleteOAuthApp;
}
exports.deleteOAuthApp = deleteOAuthApp;
/**
 * Retrieves a list of OAuth apps, given the provided paging, filtering, and sorting.
 *
 *
 * Query OAuth Apps runs with these defaults, which you can override:
 * + Results are sorted by `id` in descending order.
 * + `paging.offset` is `0`.
 */
function queryOAuthApps(payload) {
    function __queryOAuthApps({ host }) {
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'POST',
            methodFqn: 'wix.headless.v1.OAuthAppService.QueryOAuthApps',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps/query',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'oAuthApps.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __queryOAuthApps;
}
exports.queryOAuthApps = queryOAuthApps;
/**
 * Generates a secret for an existing OAuth app.
 *
 *
 * > **Note:** You can only generate a secret once for each OAuth app, and the secret can't be retrieved later. Store the secret securely.
 */
function generateOAuthAppSecret(payload) {
    function __generateOAuthAppSecret({ host }) {
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'POST',
            methodFqn: 'wix.headless.v1.OAuthAppService.GenerateOAuthAppSecret',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps/{oAuthAppId}/generate-secret',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __generateOAuthAppSecret;
}
exports.generateOAuthAppSecret = generateOAuthAppSecret;
//# sourceMappingURL=headless-v1-o-auth-app-o-auth-apps.http.js.map