import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { GenerateOAuthAppSecretResponse, OAuthApp, OAuthAppCreatedEnvelope, OAuthAppDeletedEnvelope, OAuthAppUpdatedEnvelope, OAuthAppsQueryBuilder, UpdateOAuthApp } from './headless-v1-o-auth-app-o-auth-apps.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createOAuthApp(httpClient: HttpClient): CreateOAuthAppSignature;
interface CreateOAuthAppSignature {
    /**
     * Creates a new OAuth app for a Wix Headless client.
     *
     * Use this API to enable headless functionality for a Wix site. An OAuth app allows external sites or apps to securely access your site's data and services using Wix APIs.
     * @param - OAuth app to create.
     * @returns Created OAuth app info.
     */
    (oAuthApp: OAuthApp): Promise<OAuthApp>;
}
export declare function getOAuthApp(httpClient: HttpClient): GetOAuthAppSignature;
interface GetOAuthAppSignature {
    /**
     * Retrieves an OAuth app by ID.
     * @param - ID of the OAuth app to retrieve.
     * @returns Retrieved OAuth app info.
     */
    (oAuthAppId: string): Promise<OAuthApp>;
}
export declare function updateOAuthApp(httpClient: HttpClient): UpdateOAuthAppSignature;
interface UpdateOAuthAppSignature {
    /**
     * Updates an OAuth app.
     *
     *
     * Only fields provided in `mask.paths` are updated.
     *
     * You can update the following fields:
     * + `name`
     * + `description`
     * + `allowedDomain`
     * + `loginUrl`
     * + `logoutUrl`
     * + `technology`
     * @param - ID of the OAuth app.
     * @param - Explicit list of fields to update. Only fields listed are updated.
     * @returns Updated OAuth app info.
     */
    (_id: string, oAuthApp: UpdateOAuthApp, mask: string[]): Promise<OAuthApp>;
}
/** @internal */
export declare function deleteOAuthApp(httpClient: HttpClient): DeleteOAuthAppSignature;
interface DeleteOAuthAppSignature {
    /**
     * Deletes an OAuth app by ID.
     *
     *
     * > **Note:** After you delete an OAuth app, an external client can no longer make API calls by authenticating with its client ID.
     * @param - ID of the OAuth app to delete.
     */
    (oAuthAppId: string): Promise<void>;
}
export declare function queryOAuthApps(httpClient: HttpClient): QueryOAuthAppsSignature;
interface QueryOAuthAppsSignature {
    /**
     * Retrieves a list of OAuth apps, given the provided paging, filtering, and sorting.
     *
     *
     * Query OAuth Apps runs with these defaults, which you can override:
     * + Results are sorted by `id` in descending order.
     * + `paging.offset` is `0`.
     */
    (): OAuthAppsQueryBuilder;
}
/** @internal */
export declare function generateOAuthAppSecret(httpClient: HttpClient): GenerateOAuthAppSecretSignature;
interface GenerateOAuthAppSecretSignature {
    /**
     * Generates a secret for an existing OAuth app.
     *
     *
     * > **Note:** You can only generate a secret once for each OAuth app, and the secret can't be retrieved later. Store the secret securely.
     * @param - ID of the OAuth app to generate a secret for.
     */
    (oAuthAppId: string): Promise<GenerateOAuthAppSecretResponse>;
}
export declare const onOAuthAppCreated: EventDefinition<OAuthAppCreatedEnvelope, "wix.headless.v1.o_auth_app_created">;
export declare const onOAuthAppDeleted: EventDefinition<OAuthAppDeletedEnvelope, "wix.headless.v1.o_auth_app_deleted">;
export declare const onOAuthAppUpdated: EventDefinition<OAuthAppUpdatedEnvelope, "wix.headless.v1.o_auth_app_updated">;
export { ActionEvent, Asset, BaseEventMetadata, CreateOAuthAppRequest, CreateOAuthAppResponse, CursorPaging, Cursors, DeleteContext, DeleteOAuthAppRequest, DeleteOAuthAppResponse, DeleteStatus, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, GenerateOAuthAppSecretRequest, GenerateOAuthAppSecretResponse, GetOAuthAppRequest, GetOAuthAppResponse, IdentificationData, IdentificationDataIdOneOf, MessageEnvelope, MetaSiteSpecialEvent, MetaSiteSpecialEventPayloadOneOf, Namespace, NamespaceChanged, OAuthApp, OAuthAppCreatedEnvelope, OAuthAppDeletedEnvelope, OAuthAppType, OAuthAppUpdatedEnvelope, OAuthAppsQueryBuilder, OAuthAppsQueryResult, OAuthTechnologies, OdeditorAssigned, OdeditorUnassigned, Paging, PagingMetadataV2, PicassoAssigned, PicassoUnassigned, PlatformQuery, PlatformQueryPagingMethodOneOf, QueryOAuthAppsRequest, QueryOAuthAppsResponse, RestoreInfo, ServiceProvisioned, ServiceRemoved, SiteCreated, SiteCreatedContext, SiteDeleted, SiteHardDeleted, SiteMarkedAsTemplate, SiteMarkedAsWixSite, SitePublished, SitePurgedExternally, SiteRenamed, SiteTransferred, SiteUndeleted, SiteUnpublished, SiteUrlChanged, SortOrder, Sorting, State, StudioAssigned, StudioUnassigned, UpdateOAuthApp, UpdateOAuthAppRequest, UpdateOAuthAppResponse, WebhookIdentityType, } from './headless-v1-o-auth-app-o-auth-apps.universal.js';
