import { renameKeysFromRESTResponseToSDKResponse } from '@wix/sdk-runtime/rename-all-nested-keys';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { EventDefinition } from '@wix/sdk-types';
import { createOAuthApp as universalCreateOAuthApp, deleteOAuthApp as universalDeleteOAuthApp, generateOAuthAppSecret as universalGenerateOAuthAppSecret, getOAuthApp as universalGetOAuthApp, queryOAuthApps as universalQueryOAuthApps, updateOAuthApp as universalUpdateOAuthApp, } from './headless-v1-o-auth-app-o-auth-apps.universal.js';
export const __metadata = { PACKAGE_NAME: '@wix/auth-management' };
export function createOAuthApp(httpClient) {
    return (oAuthApp) => universalCreateOAuthApp(oAuthApp, 
    // @ts-ignore
    { httpClient });
}
export function getOAuthApp(httpClient) {
    return (oAuthAppId) => universalGetOAuthApp(oAuthAppId, 
    // @ts-ignore
    { httpClient });
}
export function updateOAuthApp(httpClient) {
    return (_id, oAuthApp, mask) => universalUpdateOAuthApp(_id, oAuthApp, mask, 
    // @ts-ignore
    { httpClient });
}
/** @internal */
export function deleteOAuthApp(httpClient) {
    return (oAuthAppId) => universalDeleteOAuthApp(oAuthAppId, 
    // @ts-ignore
    { httpClient });
}
export function queryOAuthApps(httpClient) {
    return () => universalQueryOAuthApps(
    // @ts-ignore
    { httpClient });
}
/** @internal */
export function generateOAuthAppSecret(httpClient) {
    return (oAuthAppId) => universalGenerateOAuthAppSecret(oAuthAppId, 
    // @ts-ignore
    { httpClient });
}
export const onOAuthAppCreated = EventDefinition('wix.headless.v1.o_auth_app_created', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onOAuthAppDeleted = EventDefinition('wix.headless.v1.o_auth_app_deleted', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'undefined.createdDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onOAuthAppUpdated = EventDefinition('wix.headless.v1.o_auth_app_updated', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export { DeleteStatus, Namespace, OAuthAppType, OAuthTechnologies, SiteCreatedContext, SortOrder, State, WebhookIdentityType, } from './headless-v1-o-auth-app-o-auth-apps.universal.js';
//# sourceMappingURL=headless-v1-o-auth-app-o-auth-apps.public.js.map